==> haskell-html-entity-map-0.1.0.0-276-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-html-entity-map.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 html-entity-map
version:              0.1.0.0
visibility:           public
id:                   html-entity-map-0.1.0.0-CLiz2JppgBdKBRT02Qaspv
key:                  html-entity-map-0.1.0.0-CLiz2JppgBdKBRT02Qaspv
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/html-entity-map
synopsis:
    Map from HTML5 entity names to the corresponding Unicode text

description:
    Map from HTML5 entity names to the corresponding Unicode text.

category:             HTML
abi:                  1967f04982be6541f229d54dbc139620
exposed:              True
exposed-modules:      Data.HTML.Entities
import-dirs:          /usr/lib/ghc-9.4.8/site-local/html-entity-map-0.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/html-entity-map-0.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/html-entity-map-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-html-entity-map
hs-libraries:         HShtml-entity-map-0.1.0.0-CLiz2JppgBdKBRT02Qaspv
depends:
    base-4.17.2.1 text-2.0.2
    unordered-containers-0.2.20.1-98Hg6PuNW0XDqLHXL1727Z

haddock-interfaces:
    /usr/share/doc/haskell-html-entity-map/html/html-entity-map.haddock

haddock-html:         /usr/share/doc/haskell-html-entity-map/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-html-entity-map-0.1.0.0-277-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-html-entity-map.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 html-entity-map
version:              0.1.0.0
visibility:           public
id:                   html-entity-map-0.1.0.0-F5Qe2UIXiL32MMsfgFEqhr
key:                  html-entity-map-0.1.0.0-F5Qe2UIXiL32MMsfgFEqhr
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/html-entity-map
synopsis:
    Map from HTML5 entity names to the corresponding Unicode text

description:
    Map from HTML5 entity names to the corresponding Unicode text.

category:             HTML
abi:                  3956bada512a3cc79de1ce5c9238c4d0
exposed:              True
exposed-modules:      Data.HTML.Entities
import-dirs:          /usr/lib/ghc-9.4.8/site-local/html-entity-map-0.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/html-entity-map-0.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/html-entity-map-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-html-entity-map
hs-libraries:         HShtml-entity-map-0.1.0.0-F5Qe2UIXiL32MMsfgFEqhr
depends:
    base-4.17.2.1 text-2.0.2
    unordered-containers-0.2.20.1-IBPGLFAI2UT5SDMJrMkgk8

haddock-interfaces:
    /usr/share/doc/haskell-html-entity-map/html/html-entity-map.haddock

haddock-html:         /usr/share/doc/haskell-html-entity-map/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
